"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const dotenv = __importStar(require("dotenv"));
const RsoLogger = require("pkg-tools-logger");
const redis_1 = require("redis");
dotenv.config();
const redisConfig = {
    RedisUrl: process.env.REDIS_SERVERS || "localhost:6379",
};
class RsoRedis {
    constructor() {
        this._initialConnection = true;
        this.ready = false;
    }
    static getInstance() {
        if (!RsoRedis._instance) {
            RsoRedis._instance = new RsoRedis();
        }
        return RsoRedis._instance;
    }
    connect() {
        return __awaiter(this, void 0, void 0, function* () {
            this._client = (0, redis_1.createClient)({ url: redisConfig.RedisUrl });
            this._client
                .on("connect", () => {
                RsoLogger.info("Redis: connected");
            })
                .on("ready", () => {
                if (!this.ready) {
                    this.ready = true;
                }
                RsoLogger.info("Redis: ready");
                console.log("Connected to redis");
            })
                .on("reconnecting", () => {
                RsoLogger.info("Redis: reconnecting");
            })
                .on("end", () => {
                RsoLogger.info("Redis: end");
            })
                .on("disconnected", () => {
                RsoLogger.error("Redis: disconnected");
            })
                .on("error", function (err) {
                RsoLogger.error(`Redis: error: ${err}`);
            });
            yield this._client.connect();
        });
    }
    close() {
        var _a;
        (_a = this._client) === null || _a === void 0 ? void 0 : _a.quit();
    }
    setProp(key, value, expireAfter) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this._client) {
                const result = yield this._client.setEx(key, expireAfter, value);
                if (result != "OK") {
                    RsoLogger.error("Redis error. Can not set value");
                }
            }
        });
    }
    getProp(key) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this._client) {
                const data = (yield this._client.get(key)) || "";
                return data;
            }
            else {
                RsoLogger.error("Redis error. Can not get value");
            }
        });
    }
}
module.exports = RsoRedis;
